==> huaweicloudsdksecmaster-3.1.69-py2.py3-none-any.whl: huaweicloudsdksecmaster/v2/model/dataobject_search_condition_conditions.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DataobjectSearchConditionConditions:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'data': 'list[DataobjectSearchConditionData]'
    }

    attribute_map = {
        'name': 'name',
        'data': 'data'
    }

    def __init__(self, name=None, data=None):
        """DataobjectSearchConditionConditions

        The model defined in huaweicloud sdk

        :param name: 表达式名称
        :type name: str
        :param data: 表达式内容
        :type data: list[:class:`huaweicloudsdksecmaster.v2.DataobjectSearchConditionData`]
        """
        
        

        self._name = None
        self._data = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if data is not None:
            self.data = data

    @property
    def name(self):
        """Gets the name of this DataobjectSearchConditionConditions.

        表达式名称

        :return: The name of this DataobjectSearchConditionConditions.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DataobjectSearchConditionConditions.

        表达式名称

        :param name: The name of this DataobjectSearchConditionConditions.
        :type name: str
        """
        self._name = name

    @property
    def data(self):
        """Gets the data of this DataobjectSearchConditionConditions.

        表达式内容

        :return: The data of this DataobjectSearchConditionConditions.
        :rtype: list[:class:`huaweicloudsdksecmaster.v2.DataobjectSearchConditionData`]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this DataobjectSearchConditionConditions.

        表达式内容

        :param data: The data of this DataobjectSearchConditionConditions.
        :type data: list[:class:`huaweicloudsdksecmaster.v2.DataobjectSearchConditionData`]
        """
        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataobjectSearchConditionConditions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdksecmaster-3.1.79-py2.py3-none-any.whl: huaweicloudsdksecmaster/v2/model/dataobject_search_condition_conditions.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DataobjectSearchConditionConditions:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'data': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'data': 'data'
    }

    def __init__(self, name=None, data=None):
        """DataobjectSearchConditionConditions

        The model defined in huaweicloud sdk

        :param name: 表达式名称
        :type name: str
        :param data: 表达式内容列表
        :type data: list[str]
        """
        
        

        self._name = None
        self._data = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if data is not None:
            self.data = data

    @property
    def name(self):
        """Gets the name of this DataobjectSearchConditionConditions.

        表达式名称

        :return: The name of this DataobjectSearchConditionConditions.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DataobjectSearchConditionConditions.

        表达式名称

        :param name: The name of this DataobjectSearchConditionConditions.
        :type name: str
        """
        self._name = name

    @property
    def data(self):
        """Gets the data of this DataobjectSearchConditionConditions.

        表达式内容列表

        :return: The data of this DataobjectSearchConditionConditions.
        :rtype: list[str]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this DataobjectSearchConditionConditions.

        表达式内容列表

        :param data: The data of this DataobjectSearchConditionConditions.
        :type data: list[str]
        """
        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataobjectSearchConditionConditions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
